<?php
/* QuickCal support functions
------------------------------------------------------------------------------- */

// Theme init priorities:
// 9 - register other filters (for installer, etc.)
if (!function_exists('malta_quickcal_theme_setup9')) {
	add_action( 'after_setup_theme', 'malta_quickcal_theme_setup9', 9 );
	function malta_quickcal_theme_setup9() {
		if (malta_exists_quickcal()) {
			add_action( 'wp_enqueue_scripts', 							'malta_quickcal_frontend_scripts', 1100 );
			add_filter( 'malta_filter_merge_styles',					'malta_quickcal_merge_styles' );
			add_filter( 'malta_filter_get_css',						'malta_quickcal_get_css', 10, 3 );
		}
		if (is_admin()) {
			add_filter( 'malta_filter_tgmpa_required_plugins',		'malta_quickcal_tgmpa_required_plugins' );
		}
	}
}

// Check if plugin installed and activated
if ( !function_exists( 'malta_exists_quickcal' ) ) {
	function malta_exists_quickcal() {
		return class_exists('quickcal_plugin');
	}
}

// Filter to add in the required plugins list
if ( !function_exists( 'malta_quickcal_tgmpa_required_plugins' ) ) {
	
	function malta_quickcal_tgmpa_required_plugins($list=array()) {
		if (false && in_array('quickcal', malta_storage_get('required_plugins'))) {
			$path = malta_get_file_dir('plugins/quickcal/quickcal.zip');
			$list[] = array(
					'name' 		=> esc_html__('QuickCal', 'malta'),
					'slug' 		=> 'quickcal',
					'version'   => '1.0.6',
					'source' 	=> !empty($path) ? $path : 'upload://quickcal.zip',
					'required' 	=> false
			);
		}
		return $list;
	}
}
	
// Enqueue plugin's custom styles
if ( !function_exists( 'malta_quickcal_frontend_scripts' ) ) {
	
	function malta_quickcal_frontend_scripts() {
		if (malta_is_on(malta_get_theme_option('debug_mode')) && file_exists(malta_get_file_dir('plugins/quickcal/quickcal.css')))
			wp_enqueue_style( 'malta-quickcal',  malta_get_file_url('plugins/quickcal/quickcal.css'), array(), null );
	}
}
	
// Merge custom styles
if ( !function_exists( 'malta_quickcal_merge_styles' ) ) {
	
	function malta_quickcal_merge_styles($list) {
		$list[] = 'plugins/quickcal/quickcal.css';
		return $list;
	}
}



// Add plugin's specific styles into color scheme
//------------------------------------------------------------------------

// Add styles into CSS
if ( !function_exists( 'malta_quickcal_get_css' ) ) {
	
	function malta_quickcal_get_css($css, $colors, $fonts) {
		if (isset($css['fonts']) && $fonts) {
			$css['fonts'] .= <<<CSS

CSS;
		}

		if (isset($css['colors']) && $colors) {
			$css['colors'] .= <<<CSS

/* New */

body div.booked-calendar-wrap div.booked-calendar .bc-body .bc-row.week div.bc-col {
	color: {$colors['text_dark']};
	border-color: {$colors['bd_color']};
}

body div.booked-calendar-wrap div.booked-calendar .bc-body .bc-row.week div.bc-col.next-month .date,
body div.booked-calendar-wrap div.booked-calendar .bc-body .bc-row.week div.bc-col.prev-month .date,
body div.booked-calendar-wrap div.booked-calendar .bc-body .bc-row.week div.bc-col.prev-date:hover .date,
body div.booked-calendar-wrap div.booked-calendar .bc-body .bc-row.week div.bc-col.prev-date .date {
	color: {$colors['alter_light']}!important;
}

body div.booked-calendar-wrap div.booked-calendar .bc-body .bc-row.week div.bc-col.today.active span.date,
body div.booked-calendar-wrap div.booked-calendar .bc-body .bc-row.week div.bc-col.active span.date {
	background-color: {$colors['alter_bg_hover']}!important;
}
body div.booked-calendar-wrap div.booked-calendar .bc-body .bc-row.week div.bc-col:not(.prev-date):hover span.date {
	background-color: {$colors['alter_bg_hover']}!important;
    color: {$colors['text_dark']}!important;
}

body div.booked-calendar-wrap div.booked-calendar .bc-body .bc-row.week div.bc-col.today.prev-date .date,
body div.booked-calendar-wrap div.booked-calendar .bc-body .bc-row.week div.bc-col.today .date {
	background-color: {$colors['alter_bg_color']}!important;
}

body div.booked-calendar-wrap div.booked-calendar .bc-body .bc-row.week div.bc-col.today.prev-date .date span {
    color: {$colors['alter_dark']}!important;
}
body div.booked-calendar-wrap div.booked-calendar .bc-body .bc-row.week div.bc-col.today:not(.active):not(:hover):not(.prev-date) .date span {
    color: {$colors['alter_dark']}!important;
}
body div.booked-calendar-wrap div.booked-calendar .bc-body .bc-row.entryBlock .bc-col {
	border: 20px solid {$colors['alter_bg_hover']};
}

body div.booked-calendar-wrap .booked-appt-list h2 {
	color: {$colors['text_dark']}!important;
}

body div.booked-calendar-wrap .booked-appt-list .timeslot .timeslot-time, body div.booked-calendar-wrap .booked-appt-list .timeslot .timeslot-people {
	color: {$colors['text_dark']};
}

body div.booked-calendar-wrap .booked-appt-list .timeslot .spots-available {
	color: {$colors['text_dark']};
}

body .booked-modal .bm-window p.booked-title-bar {
	background-color: {$colors['text_link']}!important;
}

body div.booked-calendar-wrap div.booked-calendar .bc-body {
	border: 1px solid {$colors['bd_color']}!important;
    margin-top: -1px;
}

body div.booked-calendar-wrap div.booked-calendar .bc-body .bc-row.week + .bc-row.week .bc-col {
	border-top: 1px solid {$colors['bd_color']};
}

body div.booked-calendar-wrap div.booked-calendar .bc-body .bc-row.week .bc-col.active .date,
body div.booked-calendar-wrap div.booked-calendar .bc-body .bc-row.week .bc-col.today:hover .date span {
	color: {$colors['text_dark']}!important;
}

CSS;
		}
		
		return $css;
	}
}
?>