<?php
/* Essential Grid support functions
------------------------------------------------------------------------------- */


// Theme init priorities:
// 9 - register other filters (for installer, etc.)
if (!function_exists('malta_essential_grid_theme_setup9')) {
	add_action( 'after_setup_theme', 'malta_essential_grid_theme_setup9', 9 );
	function malta_essential_grid_theme_setup9() {
		if (malta_exists_essential_grid()) {
			add_action( 'wp_enqueue_scripts', 							'malta_essential_grid_frontend_scripts', 1100 );
			add_filter( 'malta_filter_merge_styles',					'malta_essential_grid_merge_styles' );
			add_filter( 'malta_filter_get_css',						'malta_essential_grid_get_css', 10, 3 );
		}
		if (is_admin()) {
			add_filter( 'malta_filter_tgmpa_required_plugins',		'malta_essential_grid_tgmpa_required_plugins' );
		}
	}
}

// Check if plugin installed and activated
if ( !function_exists( 'malta_exists_essential_grid' ) ) {
	function malta_exists_essential_grid() {
        return defined( 'EG_PLUGIN_PATH' ) || defined( 'ESG_PLUGIN_PATH' );
	}
}

// Filter to add in the required plugins list
if ( !function_exists( 'malta_essential_grid_tgmpa_required_plugins' ) ) {
	
	function malta_essential_grid_tgmpa_required_plugins($list=array()) {
		if (in_array('essential-grid', malta_storage_get('required_plugins'))) {
            $path = malta_get_file_dir('plugins/essential-grid/essential-grid.zip');
			$list[] = array(
						'name' 		=> esc_html__('Essential Grid', 'malta'),
						'slug' 		=> 'essential-grid',
						'version'	=> '3.1.0',
						'source'	=> !empty($path) ? $path : 'upload://essential-grid.zip',
						'required' 	=> false
			);
		}
		return $list;
	}
}
	
// Enqueue plugin's custom styles
if ( !function_exists( 'malta_essential_grid_frontend_scripts' ) ) {
	
	function malta_essential_grid_frontend_scripts() {
		if (malta_is_on(malta_get_theme_option('debug_mode')) && file_exists(malta_get_file_dir('plugins/essential-grid/essential-grid.css')))
			wp_enqueue_style( 'malta-essential-grid',  malta_get_file_url('plugins/essential-grid/essential-grid.css'), array(), null );
	}
}
	
// Merge custom styles
if ( !function_exists( 'malta_essential_grid_merge_styles' ) ) {
	
	function malta_essential_grid_merge_styles($list) {
		$list[] = 'plugins/essential-grid/essential-grid.css';
		return $list;
	}
}



// Add plugin's specific styles into color scheme
//------------------------------------------------------------------------

// Add styles into CSS
if ( !function_exists( 'malta_essential_grid_get_css' ) ) {
	
	function malta_essential_grid_get_css($css, $colors, $fonts) {
		if (isset($css['fonts']) && $fonts) {
			$css['fonts'] .= <<<CSS

CSS;
		}

		if (isset($css['colors']) && $colors) {
			$css['colors'] .= <<<CSS

CSS;
		}
		
		return $css;
	}
}
?>